@@ -3,7 +3,7 @@
   utils.replaceGetterWithProxy(
     Object.getPrototypeOf(navigator),
     'hardwareConcurrency',
-    utils.makeHandler().getterValue(-1)
+    utils.makeHandler().getterValue(opts.hardwareConcurrency)
   )
 }, {
   opts: this.opts
